package poker.presentation.login;

import java.io.*;
import java.net.*;
import com.lutris.http.*;
import com.lutris.appserver.server.httpPresentation.*;
import com.lutris.appserver.server.user.*;
import com.lutris.util.*;
import poker.business.*;
import poker.data.user.*;
import poker.Poker;

/**
 *   Presentation Object that processes the login request and redirects
 *      to the appropriate page.
 *
 *
 * EnhyDraw!, beta 4, 5/21/99
 *
 * Copyright 1999, Larry Wolcot & Daryl Tempesta
 * ALL rights reserved. Not for commercial use
 * without written permission from both authors.
 *
 * @author Shawn McMurdo, Larry Wolcott
 * @version $Revision: 1.1 $
 */
public class LoginProcessorPresentation implements HttpPresentation{

//    private final String toomanylogins = "Login failed: Exceeded maximum number of sessions.";
    private GameManager gameManager;
    private final String homePage = "main/PlaceBetPresentation.po";
    private final String loginPage = "login/LoginPresentation.po";
    private final String debugArg = "debug";
    private final String helpArg = "help";

  public void run(HttpPresentationComms comms) throws Exception {

    Poker application = (Poker)comms.application;
    gameManager = application.getGameManager();

    String username = comms.request.getParameter("username");
    String pw = comms.request.getParameter("pw");
    String cashAsString = comms.request.getParameter("cash");

    String redirect = loginPage + "?" + "pw=" + pw + "&" +
                                        "username=" + username + "&" +
                                        "cash=" + cashAsString;

    if( username==null || pw==null ) {
        comms.session.getSessionData().set("loginMessage",
                      "You must specify a username and password to login.");
        throw new ClientPageRedirectException(
                  comms.request.getAppFileURIPath(redirect));
    }

    int cash = 0;
    if(cashAsString != null && !cashAsString.equals("")) {
      try {
       cash = Integer.parseInt(cashAsString);
      }
      catch( NumberFormatException e ) {
        comms.session.getSessionData().set("loginMessage",
                                            "Invalid input in cash field!");
        throw new ClientPageRedirectException(
                  comms.request.getAppFileURIPath(redirect));
      }
    }

    if( cash < 0 || cash > 1000000 ) {
        comms.session.getSessionData().set("error",
                      "Cash amount can't be negative or greather than 1000000!");
        throw new ClientPageRedirectException(
                  comms.request.getAppFileURIPath(redirect));
    }

    //String id = comms.request.getParameter("id");
//vr    String id = comms.session.getSessionKey();

    boolean auth = false;

    if ((!username.equals("")) && (!pw.equals(""))){
       auth = gameManager.authenticate(username, pw);
    }

    if (!auth){
      comms.session.getSessionData().set("loginMessage",
                                          "Invalid username or password.");
       //comms.session.getSessionData().set("oname", username);
    }
    else {
      PokerGame game = (PokerGame)gameManager.getGame(username);
      game.setCash(game.getCash()+cash);
      comms.session.setUser(game.getPlayer());
      comms.session.getSessionData().set("game", game);
      redirect = homePage;
    }

    throw new ClientPageRedirectException(
              comms.request.getAppFileURIPath(redirect));
  }

}
